/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: DeployerMBean.java 9 2006-02-19 18:53:32Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.deployer;

import javax.management.InstanceNotFoundException;
import javax.management.MBeanException;
import javax.management.RuntimeOperationsException;
import javax.management.modelmbean.InvalidTargetObjectTypeException;

import org.apache.commons.modeler.BaseModelMBean;

/**
 * Exposed MBean for the Deployer class.
 * @author Florent Benoit
 */
public final class DeployerMBean extends BaseModelMBean implements IDeployer {

    /**
     * Create the mbean.
     * @throws MBeanException if the super constructor fails.
     */
    public DeployerMBean() throws MBeanException {
        super();
    }


    /**
     * @return the deployer (managed object)
     */
    private IDeployer getDeployer() {
        IDeployer deployer = null;
        try {
            deployer = (IDeployer) getManagedResource();
        } catch (InstanceNotFoundException e) {
            throw new IllegalStateException("Cannot get the managed resource of the MBean", e);
        } catch (RuntimeOperationsException e) {
            throw new IllegalStateException("Cannot get the managed resource of the MBean", e);
        } catch (MBeanException e) {
            throw new IllegalStateException("Cannot get the managed resource of the MBean", e);
        } catch (InvalidTargetObjectTypeException e) {
            throw new IllegalStateException("Cannot get the managed resource of the MBean", e);
        }
        return deployer;
    }

    /**
     * Deploy a file on the EJB3 container.
     * @param typeparam type of the file (EJB, WAR, EAR, RAR, CAR) (ModuleType
     *        of JSR88)
     * @param bfile bytes array of the file
     * @param filename basename of the file to be deployed
     * @return the path of the deployed file
     */
    public String deployFile(final Integer typeparam, final java.lang.Byte[] bfile, final String filename) {
        return getDeployer().deployFile(typeparam, bfile, filename);
    }

    /**
     * Deploy an application packaged in a EAR file.
     * @param fileName the name of the file to deploy
     */
    public void deployEar(final String fileName) {
        getDeployer().deployEar(fileName);
    }

    /**
     * Deploy an EJB packaged in a JAR file.
     * @param fileName the name of the file to deploy
     */
    public void deployEjbJar(final String fileName) {
        getDeployer().deployEjbJar(fileName);
    }

}

