/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JavaxEjbAroundInvokeVisitor.java 80 2006-03-01 14:58:33Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.deployment.annotations.analyzer.method;

import org.objectweb.easybeans.deployment.annotations.analyzer.AbsAnnotationVisitor;
import org.objectweb.easybeans.deployment.annotations.analyzer.AnnotationType;
import org.objectweb.easybeans.deployment.annotations.metadata.MethodAnnotationMetadata;

/**
 * This class manages the handling of &#64;{@link javax.ejb.AroundInvoke}
 * annotation.
 * @author Florent Benoit
 */
public class JavaxEjbAroundInvokeVisitor extends AbsAnnotationVisitor<MethodAnnotationMetadata> implements AnnotationType {

    /**
     * Type of annotation.
     */
    public static final String TYPE = "Ljavax/ejb/AroundInvoke;";

    /**
     * Constructor.
     * @param methodAnnotationMetadata linked to a method metadata.
     */
    public JavaxEjbAroundInvokeVisitor(final MethodAnnotationMetadata methodAnnotationMetadata) {
        super(methodAnnotationMetadata);
    }

    /**
     * Visits the end of the annotation.<br>
     * Creates the object and store it.
     */
    @Override
    public void visitEnd() {
        // set flag on method
        getAnnotationMetadata().setAroundInvoke(true);

        // set around method on super class
        getAnnotationMetadata().getClassAnnotationMetadata().addAroundInvokeMethodMetadata(getAnnotationMetadata());

    }

    /**
     * @return type of the annotation (its description)
     */
    public String getType() {
        return TYPE;
    }

}
