/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: MBeansHelper.java 9 2006-02-19 18:53:32Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.jmx;

import javax.management.InstanceNotFoundException;
import javax.management.MBeanException;
import javax.management.RuntimeOperationsException;
import javax.management.modelmbean.InvalidTargetObjectTypeException;
import javax.management.modelmbean.ModelMBean;

import org.apache.commons.modeler.ManagedBean;
import org.apache.commons.modeler.Registry;

import org.objectweb.easybeans.deployer.Deployer;

/**
 * Creates the MBeans and register them.
 * @author florent
 *
 */
public final class MBeansHelper {


    /**
     * Utility class, no public constructor.
     */
    private MBeansHelper() {

    }

    /**
     * Init all MBeans of this EJB3 container.
     * @throws MBeansException if MBeans are not created.
     */
    public static void initMBeans() throws MBeansException {
        Registry registry = null;
        try {
            registry = CommonsModelerHelper.getRegistry();
        } catch (CommonsModelerException e) {
            throw new MBeansException("Cannot get registry object", e);
        }

        // Deployer
        createMBeanDeployer(registry);
    }

    /**
     * Create the Deployer MBean (and register it).
     * @param registry the Commons modeler registry to lookup model
     * @throws MBeansException if the MBean is not registered.
     */
    public static void createMBeanDeployer(final Registry registry) throws MBeansException {
        ManagedBean managed = registry.findManagedBean("EJB3Deployer");

        if (managed == null) {
            throw new MBeansException("Mbean EJB3Deployer not found in the registry");
        }

        Deployer deployer = null;

        deployer = Deployer.getInstance();

        String objName = ":j2eeType=EJB3Deployer,name=EasyBeans";
        ModelMBean modelMbean = null;
        try {
            modelMbean = managed.createMBean(deployer);
        } catch (InstanceNotFoundException e) {
            throw new MBeansException("Cannot create MBean for the deployer", e);
        } catch (RuntimeOperationsException e) {
            throw new MBeansException("Cannot create MBean for the deployer", e);
        } catch (MBeanException e) {
            throw new MBeansException("Cannot create MBean for the deployer", e);
        } catch (InvalidTargetObjectTypeException e) {
            throw new MBeansException("Cannot create MBean for the deployer", e);
        }

        try {
            registry.registerComponent(modelMbean, objName, null);
        } catch (Exception e) {
            throw new MBeansException("Cannot register MBean with name '" + objName + "'.", e);
        }
    }
}
