/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ContainerTransactionRollbackExc.java 300 2006-04-03 11:39:17Z studzine $
 * --------------------------------------------------------------------------
 */
package org.objectweb.easybeans.tests.common.ejbs.base;

import java.sql.SQLException;

import javax.naming.NamingException;

import org.objectweb.easybeans.tests.common.exception.RollbackApplicationException;
import org.objectweb.easybeans.tests.common.exception.TransactionException;

/**
 * Throws an application transaction with rollback elelent set as true to verify
 * if the container manages the exceptions with the transactions.
 * @author Gisele Pinheiro Souza
 * @author Eduardo Studzinski Estima de Castro
 */
public class ContainerTransactionRollbackExc extends ContainerTransaction {

    /**
     * @see org.objectweb.easybeans.tests.common.ejbs.base.ItfContainerTransaction.
     * @param db1 the name of the first database.
     * @param db2 the name of the second database.
     * @throws Exception if an error occurs.
     */
    @Override
    public void insertCorrectTableInBothDB(final String db1, final String db2) throws Exception {
        try {
            super.insertCorrectTableInBothDB(db1, db2);
        } catch (SQLException e) {
            throw new RollbackApplicationException(e.getCause());
        }

    }

    /**
     * @see org.objectweb.easybeans.tests.common.ejbs.base.ItfContainerTransaction.
     * @param db1 the name of the first database.
     * @param db2 the name of the second databse
     * @throws Exception if an error occurs.
     */
@Override
    public void insertCorrectFirstErrorSecond(final String db1, final String db2) throws Exception {
        try {
            super.insertCorrectFirstErrorSecond(db1, db2);
        } catch (SQLException e) {
            throw new RollbackApplicationException(e.getCause());
        }
    }
    /**
     * @see org.objectweb.easybeans.tests.common.ejbs.base.ItfContainerTransaction.
     * @param dbName1 the first database where the table should be inserted.
     * @param dbName2 the second database where the table should be inserted.
     * @throws TransactionException if an IllegalStateException occurs.
     * @throws NamingException if a lookup error occurs.
     * @throws SQLException if a database error occurs.
     */
    @Override
    public void setRollbackOnly(final String dbName1, final String dbName2) throws Exception, NamingException {
        try {
            super.setRollbackOnly(dbName1, dbName2);
        } catch (SQLException e) {
            throw new RollbackApplicationException(e.getCause());
        }
    }

    /**
     * @see org.objectweb.easybeans.tests.common.ejbs.base.ItfContainerTransaction.
     * @param db1 the name of the first database.
     * @param db2 the name of the second database
     * @throws Exception if an error during the execution occurs.
     */
    @Override
    public void insertTablesUsingAuxBeanReq(final String db1, final String db2) throws Exception {
        try {
            super.insertTablesUsingAuxBeanReq(db1, db2);
        } catch (SQLException e) {
            throw new RollbackApplicationException(e.getCause());
        }
    }

    /**
     * @see org.objectweb.easybeans.tests.common.ejbs.base.ItfContainerTransaction.
     * @param db1 the name of the first database.
     * @param db2 the name of the second database
     * @throws Exception if an error during the execution occurs.
     */
    @Override
    public void insertTablesUsingAuxBeanNotSup(final String db1, final String db2) throws Exception {
        try {
            super.insertTablesUsingAuxBeanNotSup(db1, db2);
        } catch (SQLException e) {
            throw new RollbackApplicationException(e.getCause());
        }

    }

}
