/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: AllLifecycleResourceAccess00Interceptor.java 231 2006-03-20 10:27:02Z studzine $
 * --------------------------------------------------------------------------
 */
package org.objectweb.easybeans.tests.common.interceptors.lifecycle;

import javax.annotation.PostConstruct;
import javax.annotation.PreDestroy;
import javax.ejb.InvocationContext;
import javax.ejb.PostActivate;
import javax.ejb.PrePassivate;

import org.objectweb.easybeans.tests.common.exception.IllegalException;
import org.objectweb.easybeans.tests.common.resources.ResourceTester;

/**
 * This interceptor contains the four life cycle callbacks interceptors method.
 * Every method try to access the "java:comp/env".
 * @author Eduardo Studzinski Estima de Castro
 * @author Gisele Pinheiro Souza
 *
 */
public class AllLifecycleResourceAccess00Interceptor extends ResourceTester{
    //TODO: test case

    /**
     * PostActivate that access a resource by dependency injection.
     * @param ic contains attributes of invocation
     */
    @PostActivate
    public void postActivate(final InvocationContext ic){
        this.intercept(ic);
    }

    /**
     * PostConstruct that access a resource by dependency injection.
     * @param ic contains attributes of invocation
     */
    @PostConstruct
    public void postConstruct(final InvocationContext ic){
        this.intercept(ic);
    }

    /**
     * PreDestroy that access a resource by dependency injection.
     * @param ic contains attributes of invocation
     */
    @PreDestroy
    public void preDestroy(final InvocationContext ic){
        this.intercept(ic);
    }

    /**
     * PrePassivate that access a resource by dependency injection.
     * @param ic contains attributes of invocation
     */
    @PrePassivate
    public void prePassivate(final InvocationContext ic){
        this.intercept(ic);
    }

    /**
     * Test resource access.
     * @param ic contains attributes of invocation
     */
    private void intercept(final InvocationContext ic){
        try {
            super.access00();
            ic.proceed();
        } catch (Exception e) {
            throw new IllegalException("Access Exception.", e);
        }
    }
}
