/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: TestSFAccessInterceptor00.java 312 2006-04-04 07:30:45Z studzine $
 * --------------------------------------------------------------------------
 */
package org.objectweb.easybeans.tests.interceptors.business.stateful.containermanaged;

import static org.objectweb.easybeans.tests.common.helper.EJBHelper.getBeanRemoteInstance;

import javax.naming.NameNotFoundException;

import org.objectweb.easybeans.tests.common.ejbs.base.ItfAccessEJB;
import org.objectweb.easybeans.tests.common.ejbs.base.ItfAccessEMFactory;
import org.objectweb.easybeans.tests.common.ejbs.base.ItfAccessEntityManager;
import org.objectweb.easybeans.tests.common.ejbs.base.ItfAccessJNDI;
import org.objectweb.easybeans.tests.common.ejbs.base.ItfAccessResourceManager;
import org.objectweb.easybeans.tests.common.ejbs.base.ItfAccessSessionContext;
import org.objectweb.easybeans.tests.common.ejbs.base.ItfAccessTimerService;
import org.objectweb.easybeans.tests.common.ejbs.base.ItfAccessUserTransaction;
import org.objectweb.easybeans.tests.common.ejbs.stateful.containermanaged.SFSBAccessInterceptorTest00;
import org.objectweb.easybeans.tests.common.ejbs.stateful.containermanaged.SFSBAccessSessionContextInterceptorTest00;
import org.objectweb.easybeans.tests.common.ejbs.stateful.containermanaged.SFSBAccessSessionContextInterceptorTest01;
import org.objectweb.easybeans.tests.common.ejbs.stateful.containermanaged.SFSBAccessTimerServiceInterceptorTest00;
import org.objectweb.easybeans.tests.common.ejbs.stateful.containermanaged.SFSBAccessUserTransactionInterceptorTest00;
import org.objectweb.easybeans.tests.interceptors.business.base.BaseAccessOperationsInterceptor00;
import org.testng.annotations.Configuration;
import org.testng.annotations.ExpectedExceptions;
import org.testng.annotations.Test;

/**
 * Verifies if interceptors in an external class can access the perform the
 * operations specified by the JSR-220.
 * @reference JSR220-PROPOSED FINAL - Chapter 4 - Table 2
 * @requirement Application Server must be running; the beans
 *              org.objectweb.easybeans.tests.common.ejbs.stateless.containermanaged.SFSB*AccessInterceptor*
 *              must be deployed.
 * @setup gets the reference of SFSBAccessInterceptorTest00, SFSBAccessTimerServiceInterceptorTest00
 * @author Eduardo Studzinski Estima de Castro
 * @author Gisele Pinheiro Souza
 */
public class TestSFAccessInterceptor00 extends BaseAccessOperationsInterceptor00 {

    /**
     * Gets bean instances used in the tests.
     * @throws Exception if there is a problem with the bean initialization.
     */
    @Configuration(beforeTestClass = true)
    public void startUp() throws Exception {
        ItfAccessJNDI bean00 = getBeanRemoteInstance(SFSBAccessInterceptorTest00.class, ItfAccessJNDI.class);
        ItfAccessEJB bean01 = getBeanRemoteInstance(SFSBAccessInterceptorTest00.class, ItfAccessEJB.class);
        ItfAccessResourceManager bean02 = getBeanRemoteInstance(SFSBAccessInterceptorTest00.class,
                ItfAccessResourceManager.class);
        ItfAccessEntityManager bean03 = getBeanRemoteInstance(SFSBAccessInterceptorTest00.class,
                ItfAccessEntityManager.class);
        ItfAccessEMFactory bean04 = getBeanRemoteInstance(SFSBAccessInterceptorTest00.class, ItfAccessEMFactory.class);
        ItfAccessSessionContext bean05 = getBeanRemoteInstance(SFSBAccessInterceptorTest00.class,
                ItfAccessSessionContext.class);
        ItfAccessTimerService bean06 = getBeanRemoteInstance(SFSBAccessTimerServiceInterceptorTest00.class,
                ItfAccessTimerService.class);

        ItfAccessSessionContext bean08 = getBeanRemoteInstance(SFSBAccessSessionContextInterceptorTest00.class,
                ItfAccessSessionContext.class);
        ItfAccessSessionContext bean09 = getBeanRemoteInstance(SFSBAccessSessionContextInterceptorTest01.class,
                ItfAccessSessionContext.class);
        super.setBeans(bean00, bean01, bean02, bean03, bean04, bean05, bean06, null, bean08, bean09);
    }

    /**
     * Verifies if the interceptor can access the "java:comp/env" via JNDI. This
     * operation is allowed, so there isn't an expected
     * exception.
     * @input -
     * @output no exceptions.
     * @throws Exception if a problem occurs.
     */
    @Override
    @Test(groups = {"java:comp/env access"})
    public void testJNDI00() throws Exception {
        super.testJNDI00();
    }

    /**
     * Verifies if the interceptor can access an EJB. This
     * operation is allowed, so there isn't an expected
     * exception.
     * @input -
     * @output no exceptions.
     * @throws Exception if a problem occurs.
     */
    @Override
    @Test(groups = {"EJB access"})
    public void testEJB00() throws Exception {
        super.testEJB00();
    }

    /**
     * Verifies if the interceptor can access the resource manager. This
     * operation is allowed, so there isn't an expected
     * exception.
     * @input -
     * @output no exceptions.
     * @throws Exception if a problem occurs.
     */
    @Override
    @Test(groups = {"Resource access"})
    public void testResource00() throws Exception {
        super.testResource00();
    }

    /**
     * Verifies if the interceptor can access the entity manager. This
     * operation is allowed, so there isn't an expected
     * exception.
     * @input -
     * @output no exceptions.
     * @throws Exception if a problem occurs.
     */
    @Override
    @Test(groups = {"Entity Manager access"})
    public void testEntityManager00() throws Exception {
        super.testEntityManager00();
    }

    /**
     * Verifies if the interceptor can access the entity factory. This
     * operation is allowed, so there isn't an expected
     * exception.
     * @input -
     * @output no exceptions.
     * @throws Exception if a problem occurs.
     */
    @Override
    @Test(groups = {"Entity Factory access"})
    public void testEntityFactory00() throws Exception {
        super.testEntityFactory00();
    }

    /**
     * Verifies if the interceptor can access the session context. This
     * operation is allowed, so there isn't an expected
     * exception.
     * @input -
     * @output no exceptions.
     * @throws Exception if a problem occurs.
     */
    @Override
    @Test(groups = {"SessionContext access"})
    public void testSessionContext00() throws Exception {
        super.testSessionContext00();
    }

    /**
     * Verifies if an interceptor can access the "getTimerService()" of a SessionContext instance.
     * The specification defines that if a bean instance attempts to invoke a method and that access is not allowed, the container
     * must throw the java.lang.IllegalStateException.
     * @input -
     * @output java.lang.IllegalStateException.
     * @throws Exception if a problem occurs.
     */
    @Override
    @Test(groups = {"SessionContext access"})
    @ExpectedExceptions({IllegalStateException.class})
    public void testSessionContext01() throws Exception {
        super.testSessionContext01();
    }

    /**
     * Verifies if an interceptor can access the "getUserTransaction()" of a SessionContext instance.
     * The specification defines that if a bean instance attempts to invoke a method and that access is not allowed, the container
     * must throw the java.lang.IllegalStateException.
     * @input -
     * @output java.lang.IllegalStateException.
     * @throws Exception if a problem occurs.
     */
    @Override
    @Test(groups = {"SessionContext access"})
    @ExpectedExceptions({IllegalStateException.class})
    public void testSessionContext02() throws Exception {
        super.testSessionContext02();
    }

    /**
     * Verifies if an interceptor can access the timer service.
     * The specification denies the use of this service, the container
     * must throw the java.lang.IllegalStateException.
     * @input -
     * @output java.lang.IllegalStateException.
     * @throws Exception if a problem occurs.
     */
    @Override
    @Test(groups = {"TimerService access"})
    @ExpectedExceptions(IllegalStateException.class)
    public void testTimerService00() throws Exception {
        super.testTimerService00();
    }

    /**
     * Verifies if an interceptor can access the user transaction.
     * The specification denies the use of this service, the container
     * must throw the javax.naming.NameNotFoundException
     * @input -
     * @output javax.naming.NameNotFoundException
     * @throws Exception if a problem occurs.
     */
    @Override
    @Test(groups = {"UserTransaction access"})
    @ExpectedExceptions({NameNotFoundException.class})
    @SuppressWarnings("unused")
    public void testUserTransaction00() throws Exception {
        ItfAccessUserTransaction bean = getBeanRemoteInstance(SFSBAccessUserTransactionInterceptorTest00.class,
                ItfAccessUserTransaction.class);
    }

}
